@@ -4,13 +4,15 @@ from .dispatcher import (
     Event,
     EventType,
     MediaGroupContentType,
-    AbstractHandler,
     AbstractEventHandler,
     AbstractErrorHandler,
     AbstractEventFilter,
     AbstractErrorFilter,
     Middleware,
-    RateLimiter
+    RateLimit,
+    Limit,
+    get_event_chat_id,
+    get_event_user_id
 )
 from .state_machine import StateMachine, State, AbstractStateStorage
 from .context import (
@@ -35,13 +37,14 @@ __all__ = [
     "Dispatcher",
     "Event",
     "EventType",
-    "AbstractHandler",
+    "MediaGroupContentType",
     "AbstractEventHandler",
     "AbstractErrorHandler",
     "AbstractEventFilter",
     "AbstractErrorFilter",
     "Middleware",
-    "RateLimiter",
+    "RateLimit",
+    "Limit",
     "StateMachine",
     "State",
     "AbstractStateStorage",
@@ -53,7 +56,9 @@ __all__ = [
     "NamedSet",
     "AbstractCallbackDataBuilder",
     "TaskExecutor",
-    "Env"
+    "Env",
+    "get_event_chat_id",
+    "get_event_user_id"
 ]
 
 
