@@ -2,7 +2,6 @@ from typing import Pattern
 
 from telebox.dispatcher.filters.error_filter import AbstractErrorFilter
 from telebox.dispatcher.typing import Event
-from telebox.dispatcher.enums.event_type import EventType
 
 
 class ErrorRegExpTextFilter(AbstractErrorFilter):
@@ -14,7 +13,7 @@ class ErrorRegExpTextFilter(AbstractErrorFilter):
         self._patterns = set(patterns)
         self._full_match = full_match
 
-    def get_value(self, error: Exception, event: Event, event_type: EventType) -> str:
+    def get_value(self, error: Exception, event: Event) -> str:
         return str(error)
 
     def check_value(self, value: str) -> bool:
