@@ -1,6 +1,6 @@
 from telebox.dispatcher.filters.event_filter import AbstractEventFilter
 from telebox.dispatcher.enums.event_type import EventType
-from telebox.dispatcher.media_group import MediaGroup
+from telebox.dispatcher.utils.media_group import MediaGroup
 from telebox.dispatcher.enums.media_group_content_type import MediaGroupContentType
 
 
@@ -15,7 +15,7 @@ class MediaGroupContentTypeFilter(AbstractEventFilter):
     def get_event_types(self) -> set[EventType]:
         return {EventType.MEDIA_GROUP}
 
-    def get_value(self, event: MediaGroup, event_type: EventType) -> set[MediaGroupContentType]:
+    def get_value(self, event: MediaGroup) -> set[MediaGroupContentType]:
         return event.content_types
 
     def check_value(self, value: set[MediaGroupContentType]) -> bool:
