@@ -8,7 +8,7 @@ class NoneFilter(AbstractEventFilter):
     def get_event_types(self) -> set[EventType]:
         return set(EventType)
 
-    def get_value(self, event: Event, event_type: EventType) -> bool:
+    def get_value(self, event: Event) -> bool:
         return True
 
     def check_value(self, value: bool) -> bool:
