@@ -2,7 +2,7 @@ from typing import Optional, Union
 
 from telebox.dispatcher.filters.event_filter import AbstractEventFilter
 from telebox.dispatcher.enums.event_type import EventType
-from telebox.dispatcher.media_group import MediaGroup
+from telebox.dispatcher.utils.media_group import MediaGroup
 from telebox.telegram_bot.types.types.message import Message
 from telebox.telegram_bot.types.types.callback_query import CallbackQuery
 from telebox.state_machine.state import State
@@ -28,11 +28,7 @@ class StateFilter(AbstractEventFilter):
             EventType.CALLBACK_QUERY
         }
 
-    def get_value(
-        self,
-        event: Union[Message, MediaGroup, CallbackQuery],
-        event_type: EventType
-    ) -> Optional[State]:
+    def get_value(self, event: Union[Message, MediaGroup, CallbackQuery]) -> Optional[State]:
         if event.chat_id is not None:
             return self._machine.get_state(chat_id=event.chat_id, user_id=event.user_id)
 
