@@ -1,7 +1,6 @@
 from telebox.dispatcher.middlewares.middleware import Middleware
 from telebox.dispatcher.typing import Event
 from telebox.dispatcher.enums.event_type import EventType
-from telebox.telegram_bot.types.types.callback_query import CallbackQuery
 from telebox.utils.callback_data_builders.builder import AbstractCallbackDataBuilder
 
 
@@ -11,5 +10,5 @@ class CallbackDataMiddleware(Middleware):
         self._builder = builder
 
     def process_event(self, event: Event, event_type: EventType) -> None:
-        if isinstance(event, CallbackQuery):
+        if event_type is EventType.CALLBACK_QUERY:
             _, event.data = self._builder.parse(event.data)
