@@ -1,2 +1,8 @@
 from .update_content_type import UpdateContentType
 from .message_content_type import MessageContentType
+
+
+__all__ = [
+    "UpdateContentType",
+    "MessageContentType"
+]
