@@ -5,14 +5,14 @@ import ujson
 from telebox.utils.callback_data_builders.builder import AbstractCallbackDataBuilder
 
 
-FilterKey = Union[str, int]
+Key = Union[str, int]
 Value = Union[str, int, float, bool, list, None]
 
 
 class JSONCallbackDataBuilder(AbstractCallbackDataBuilder):
 
-    def build(self, filter_key: FilterKey, value: Value = None) -> str:
-        return ujson.dumps([filter_key, value])
+    def build(self, key: Key, value: Value = None) -> str:
+        return ujson.dumps([key, value])
 
-    def parse(self, data: str) -> tuple[FilterKey, Value]:
+    def parse(self, data: str) -> tuple[Key, Value]:
         return tuple(ujson.loads(data))
